package com.message

import android.app.Application
import android.content.BroadcastReceiver
import android.content.Context
import android.content.Intent
import android.content.IntentFilter
import android.net.ConnectivityManager
import android.net.wifi.WifiManager
import android.provider.Telephony.Sms.Intents.SMS_RECEIVED_ACTION
import android.support.v4.content.LocalBroadcastManager
import com.bluefay.core.BLLog
import org.greenrobot.eventbus.EventBus


/**
 * OP_Receiver log
 */
const val OP_Receiver_ACTION_LOG = "ONEPIXEL_ACTION_LOG"

/**
 * 网络是否可用(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_INTERNET_ACCESS_ENABLED = "wifi.intent.action.INTERNET_ACCESS_ENABLED"

/**
 * push 透传广播(建议使用事件总线）
 * @see MessageEvent
 */
const val ACTION_TRANSFER = "com.lantern.wifilocating.push.action.TRANSFER"

/**
 * 获取OneId 广播 (建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_ONEID = "OneIdInitReceiver"

/**
 * Feed 展示 (建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_FEED_DISPLAY = "wifi.intent.action.FEED_DISPLAY"

/**
 * Broadcast intent action sent by the download manager when a download
 * completes.(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_DOWNLOAD_COMPLETE = "android.intent.action.DOWNLOAD_COMPLETE"

/**
 * 下载状态变化广播(建议使用事件总线)
 *  @see MessageEvent
 */
const val ACTION_DOWNLOAD_STATUS_CHANGED = "android.intent.action.DOWNLOAD_STATUS_CHANGED"

/**
 * Broadcast intent action sent by the download manager when a download
 * completes.(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_DOWNLOAD_REMOVE = "android.intent.action.DOWNLOAD_REMOVE"

/**
 * 下载引导动画  (建议使用事件总线)
 * @see MessageEvent
 */
const val DOWNLOAD_ANIM_ACTION = "com.lantern.launcher.downloadnewguide.DOWNLOAD_ANIM"


/**
 * 网页分析完成  (建议使用事件总线)
 * @see MessageEvent
 */
const val WEBPAGE_TASK_FINISH = "com.lantern.analyzer.webpage_task_finish"

/**
 * 登录鉴权 SDK 消息  (建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_AUTH_SDK = "wifi.intent.action.AUTHSDK_MESSAGE"

/**
 * 守护服务启动  (建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_DAEMON_SERVICE_START = "com.lantern.daemon.intent.action.SERVICE_START_NOTIFY"

/**
 * 天气  关闭弹框本地广播(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_CLOSE_POP_WIN = "action_wifi_sktq_close_pop_win"

/**
 * 天气 安装包下载完成(建议使用事件总线)
 * @see MessageEvent
 */
const val SKTQ_DOWNLOAD_COMPLETE_EVENT = "SKTQ_DOWNLOAD_COMPLETE_EVENT"

/**
 * 透传登录？
 */
const val WK_LOGIN_GET_MOBILE_ACTION = "com.lantern.auth.action.MOBILE"

/**
 * 鉴权码？
 */
const val WK_LOGIN_GET_CODE_ACTION = "com.lantern.auth.action.CODE"

/**
 * 收到push消息，需要退出登录(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_PUSH_LOGOUT = "com.wifi.intent.action.PUSH_LOGOUT"

/**
 * 发送短信(建议使用事件总线)
 * @see MessageEvent
 */
const val SENT_SMS_ACTION = "SENT_SMS_ACTION"

/**
 * Feed 相关(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_CMT_REPOST = "wifi.intent.action.CMT_REPOST"

/**
 * Feed 相关(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_CMT_DELETE = "wifi.intent.action.CMT_DELETE"

/**
 * Feed 相关(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_CMT_REPLY_DELETE = "wifi.intent.action.CMT_REPLY_DELETE"

/**
 * Feed 相关(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_CMT_REPORT = "wifi.intent.action.CMT_REPORT"

/**
 * Feed 相关(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_CMT_REPLY_REPORT = "wifi.intent.action.CMT_REPLY_REPORT"

/**
 * Feed 相关(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_CMT_SET_USER_INFO = "wifi.intent.action.CMT_SET_USER_INFO"

/**
 * Feed 相关(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_UpdateComment = "wifi.intent.action.UpdateComment"

/**
 * Feed 相关(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_Favorite = "wifi.intent.action.Favorite"

/**
 * Feed 相关(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_HEART_BEAT = "wifi.intent.action.HEART_BEAT"

/**
 * Feed 桌面快捷 创建(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_FEED_SHORCUT_CREATE = "wifi.intent.action.FEEDSDK_SHORCUT_CREATE"

/**
 * Feed 相关(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_LY_PUBLISH_MOMENT = "lx.android.action.LY_PUBLISH_MOMENT_SUCCESS"

/**
 * Feed 相关(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_LY_SEND_MESSAGE = "lx.android.action.LY_SEND_MESSAGE_SUCCESS"

/**
 * Browser 相关(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_BROWSER_FEED_TEST = "wifi.intent.action.BROWSER_FEED_TEST"

/**
 * Browser 相关(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_BROWSER_JS_INJECT = "wifi.intent.action.BROWSER_JS_INJECT"

const val DYNAMIC_FRIENDS_THIRDPART_MSG = "com.snda.dynamic.friends.thirdpart.msg"

/**
 * Framework 添加标记(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_ADD_BADGE = "com.snda.wifilocating.ADD_BADGE"

/**
 * Framework 删除标记(建议使用事件总线)
 * @see MessageEvent
 */
const val ACTION_REMOVE_BADGE = "com.snda.wifilocating.REMOVE_BADGE"

/**
 * pushSdk 心跳事件(建议使用事件总线)
 *  @see MessageEvent
 */
const val ACTION_PUSH_HEARTBEAT_TIMER = "com.lantern.wifilocating.push.action.Heartbeat"

/**
 * pushSdk  (建议使用事件总线)
 *  @see MessageEvent
 */
const val ACTION_SYNC_TIMER = "com.lantern.push.action.SYNC"

/**
 * pushSdk  (建议使用事件总线)
 *  @see MessageEvent
 */
const val ACTION_DEBUG = "com.lantern.push.ACTION_D"

/**
 * pushSdk  (建议使用事件总线)
 *  @see MessageEvent
 */
const val ACTION_PUSH_THIRD_START = "com.lantern.wifilocating.push.action.THIRDSTART"

/**
 * 退出登录 (建议使用事件总线)
 *  @see MessageEvent
 */
const val ACTION_LOGINOUT = "wifi.intent.action.LOGINOUT"

/**
 * 连信广告接收
 */
const val LIANX_UPDATE_USERINFO_ACTION = "com.lantern.chat.mend_profile_finish"

/**
 * traffic 相关(建议使用事件总线)
 * @see MessageEvent
 */
const val PARSE_TRAFFIC_RESULT_ACTION = "com.lantern.traffic.statistics.ui.ParserTrafficResultAction"

/**
 * ANR 广播
 */
const val SYSTEM_ANR_ACTION = "android.intent.action.ANR"

/**
 *   (建议使用事件总线)
 *  @see MessageEvent
 */
const val ACTION_APP_RESPONSE = "com.lantern.feed.request.ACTION_RESPONSE"

/**
 *  应用墙 (建议使用事件总线)
 *  @see MessageEvent
 */
const val ACTION_AD_RESPONSE = "com.wifi.ad.appwall.ACTION_RESPONSE"

/**
 * WifiApHelper(建议使用事件总线)
 * @see MessageEvent
 */
const val WIFI_AP_STATE_CHANGED_ACTION = "android.net.wifi.WIFI_AP_STATE_CHANGED"

/**
 * 体检
 */
const val ACTION_INSURANCE_ACTIVATED = "wifi.intent.action.WIFI_INSURANCE_ACTIVATED"

/**
 * 神奇管家
 */
const val SQGJ_LOAD_ICON_SUCCESS = "com.lantern.sqgj.LOAD_ICON_SUCCESS"


/**
 * 以下是个厂商的alarm 广播
 */
const val ACTION_ALARM_GOOGLE = "com.android.deskclock.ALARM_ALERT"  //原生
const val ACTION_ALARM_NUBIA = "com.nubia.deskclock.ALARM_ALERT"  //Nubia
const val ACTION_ALARM_MEIZU = "com.android.alarmclock.ALARM_ALERT"  //魅族
const val ACTION_ALARM_LG = "com.lge.clock.alarmclock.ALARM_ALERT" //LG
const val ACTION_ALARM_SAMSUNG = "com.samsung.sec.android.clockpackage.alarm.ALARM_ALERT" //三星
const val ACTION_ALARM_SONY = "com.sonyericsson.alarm.ALARM_ALERT" //索尼
const val ACTION_ALARM_HTC = "com.htc.android.worldclock.ALARM_ALERT" //htc
const val ACTION_ALARM_HTC_2 = "com.htc.worldclock.ALARM_ALERT" //htc
const val ACTION_ALARM_HTC_3 = "com.htc.android.worldclock.intent.action.ALARM_ALERT" //htc
const val ACTION_ALARM_LENOVO = "com.lenovomobile.deskclock.ALARM_ALERT" //联想
const val ACTION_ALARM_LENOVO_2 = "com.lenovo.deskclock.ALARM_ALERT" //联想
const val ACTION_ALARM_VIVO = "com.cn.google.AlertClock.ALARM_ALERT" //vivo
const val ACTION_ALARM_OPPO = "com.oppo.alarmclock.alarmclock.ALARM_ALERT" //oppo
const val ACTION_ALARM_ZTE = "com.zdworks.android.zdclock.ACTION_ALARM_ALERT" //中兴

/**
 * 广播接收统一
 * 基本上自己定义的广告Action都可以使用事件总线来替换（除了有跨进程的通讯消息）
 */
object AllBroadcastReceiverHelp {
    private var broadcastReceiver: AllBroadcastReceiver

    init {
        broadcastReceiver = AllBroadcastReceiver()
    }

    fun registerReceiver(app: Application) {
        app.registerReceiver(broadcastReceiver, IntentFilter().addNormalAction())
        app.registerReceiver(broadcastReceiver, IntentFilter().addPackageAction())
        //为了兼容接收本地广播
        //LocalBroadcastManager.getInstance(app).registerReceiver(broadcastReceiver,intentFilter)
    }

    class AllBroadcastReceiver : BroadcastReceiver() {
        override fun onReceive(context: Context?, intent: Intent?) {
            BLLog.d("BroadcastMessageEvent send action:${intent?.action}")
            sendBroadcastEvent(context, intent)
        }
    }

    /**
     * 发送接收到的广播事件 使用EventBus
     */
    private fun sendBroadcastEvent(context: Context?, intent: Intent?) {

        BroadcastMessageEvent().let {
            it.context = context
            it.intent = intent
            EventBus.getDefault().post(it)
        }

    }

}

fun IntentFilter.addPackageAction():IntentFilter {
    return this.apply {
        //软件安装
        addAction(Intent.ACTION_PACKAGE_ADDED)
        //软件安装  @Deprecated
        addAction(Intent.ACTION_PACKAGE_INSTALL)
        //软件卸载
        addAction(Intent.ACTION_PACKAGE_REMOVED)
        //软件更新
        addAction(Intent.ACTION_PACKAGE_REPLACED)
        /**
         * scheme 增加
         */
        //监听应用安装时必须增加scheme，否则拿不到
        addDataScheme("package");
    }
}

/**
 * 添加普通（不需要特殊的data scheme)所有需要接收的广播 消息
 */
fun IntentFilter.addNormalAction(): IntentFilter {
    return this.apply {
        priority = IntentFilter.SYSTEM_HIGH_PRIORITY

        addAction(OP_Receiver_ACTION_LOG)
        addAction(ACTION_INTERNET_ACCESS_ENABLED)
        addAction(ACTION_TRANSFER)
        addAction(ACTION_ONEID)
        addAction(ACTION_FEED_DISPLAY)
        addAction(ACTION_DOWNLOAD_COMPLETE)
        addAction(ACTION_DOWNLOAD_STATUS_CHANGED)
        addAction(ACTION_DOWNLOAD_REMOVE)
        addAction(DOWNLOAD_ANIM_ACTION)
        addAction(WEBPAGE_TASK_FINISH)
        addAction(ACTION_AUTH_SDK)
        addAction(ACTION_DAEMON_SERVICE_START)
        addAction(ACTION_CLOSE_POP_WIN)
        addAction(SKTQ_DOWNLOAD_COMPLETE_EVENT)
        addAction(WK_LOGIN_GET_MOBILE_ACTION)
        addAction(WK_LOGIN_GET_CODE_ACTION)
        addAction(ACTION_PUSH_LOGOUT)
        addAction(SENT_SMS_ACTION)
        addAction(ACTION_CMT_REPOST)
        addAction(ACTION_CMT_DELETE)
        addAction(ACTION_CMT_REPLY_DELETE)
        addAction(ACTION_CMT_REPORT)
        addAction(ACTION_CMT_REPLY_REPORT)
        addAction(ACTION_CMT_SET_USER_INFO)
        addAction(ACTION_UpdateComment)
        addAction(ACTION_Favorite)
        addAction(ACTION_HEART_BEAT)
        addAction(ACTION_FEED_SHORCUT_CREATE)
        addAction(ACTION_LY_PUBLISH_MOMENT)
        addAction(ACTION_LY_SEND_MESSAGE)
        addAction(ACTION_BROWSER_FEED_TEST)
        addAction(ACTION_BROWSER_JS_INJECT)
        addAction(DYNAMIC_FRIENDS_THIRDPART_MSG)
        addAction(ACTION_ADD_BADGE)
        addAction(ACTION_REMOVE_BADGE)
        addAction(ACTION_PUSH_HEARTBEAT_TIMER)
        addAction(ACTION_SYNC_TIMER)
        addAction(ACTION_DEBUG)
        addAction(ACTION_PUSH_THIRD_START)
        addAction(ACTION_LOGINOUT)
        addAction(LIANX_UPDATE_USERINFO_ACTION)
        addAction(PARSE_TRAFFIC_RESULT_ACTION)
        addAction(ACTION_APP_RESPONSE)
        addAction(ACTION_AD_RESPONSE)
        addAction(WIFI_AP_STATE_CHANGED_ACTION)
        addAction(ACTION_INSURANCE_ACTIVATED)
        addAction(SQGJ_LOAD_ICON_SUCCESS)


        //wifi 状态改变
        addAction(WifiManager.WIFI_STATE_CHANGED_ACTION)
        //wifi 扫描
        addAction(WifiManager.SCAN_RESULTS_AVAILABLE_ACTION)
        //wifi rssi 改变
        addAction(WifiManager.RSSI_CHANGED_ACTION)
        //wifi 建立过程中状态改变
        addAction(WifiManager.SUPPLICANT_STATE_CHANGED_ACTION)
        //wifi 网络状态变化
        addAction(WifiManager.NETWORK_STATE_CHANGED_ACTION)
        //网络连接状态变化
        addAction(ConnectivityManager.CONNECTIVITY_ACTION)
        //监听Home键
        addAction(Intent.ACTION_CLOSE_SYSTEM_DIALOGS)

        //短信接收
        addAction(SMS_RECEIVED_ACTION)
        //亮屏
        addAction(Intent.ACTION_SCREEN_ON)
        //暗屏
        addAction(Intent.ACTION_SCREEN_OFF)
        //唤醒页面
        addAction(Intent.ACTION_USER_PRESENT)
        //分钟变化
        addAction(Intent.ACTION_TIME_TICK)
        //插电
        addAction(Intent.ACTION_POWER_CONNECTED)
        //电池变化
        addAction(Intent.ACTION_BATTERY_CHANGED)
        //日期改变
        addAction(Intent.ACTION_DATE_CHANGED)
        //ANR
        addAction(SYSTEM_ANR_ACTION)

        /**
         * 以下是个厂商的alarm 广播
         */
        addAction(ACTION_ALARM_GOOGLE)
        addAction(ACTION_ALARM_NUBIA)
        addAction(ACTION_ALARM_MEIZU)
        addAction(ACTION_ALARM_LG)
        addAction(ACTION_ALARM_SAMSUNG)
        addAction(ACTION_ALARM_SONY)
        addAction(ACTION_ALARM_HTC)
        addAction(ACTION_ALARM_HTC_2)
        addAction(ACTION_ALARM_HTC_3)
        addAction(ACTION_ALARM_LENOVO)
        addAction(ACTION_ALARM_LENOVO_2)
        addAction(ACTION_ALARM_VIVO)
        addAction(ACTION_ALARM_OPPO)
        addAction(ACTION_ALARM_ZTE)

    }
}


