/*******************************************************************************
Xiamen Yaji Software Co., Ltd., (the “Licensor”) grants the user (the “Licensee”
) non-exclusive and non-transferable rights to use the software according to
the following conditions:
a.  The Licensee shall pay royalties to the Licensor, and the amount of those
    royalties and the payment method are subject to separate negotiations
    between the parties.
b.  The software is licensed for use rather than sold, and the Licensor reserves
    all rights over the software that are not expressly granted (whether by
    implication, reservation or prohibition).
c.  The open source codes contained in the software are subject to the MIT Open
    Source Licensing Agreement (see the attached for the details);
d.  The Licensee acknowledges and consents to the possibility that errors may
    occur during the operation of the software for one or more technical
    reasons, and the Licensee shall take precautions and prepare remedies for
    such events. In such circumstance, the Licensor shall provide software
    patches or updates according to the agreement between the two parties. the
    Licensor will not assume any liability beyond the explicit wording of this
    Licensing Agreement.
e.  Where the Licensor must assume liability for the software according to
    relevant laws, the Licensor’s entire liability is limited to the annual
    royalty payable by the Licensee.
f.  The Licensor owns the portions listed in the root directory and subdirectory
    (if any) in the software and enjoys the intellectual property rights over
    those portions. As for the portions owned by the Licensor, the Licensee
    shall not:
    i.  Bypass or avoid any relevant technical protection measures in the
        products or services;
    ii. Release the source codes to any other parties;
    iii.Disassemble, decompile, decipher, attack, emulate, exploit or
        reverse-engineer these portion of code;
    iv. Apply it to any third-party products or services without Licensor’s
        permission;
    v.  Publish, copy, rent, lease, sell, export, import, distribute or lend any
        products containing these portions of code;
    vi. Allow others to use any services relevant to the technology of these
        codes; and
    vii.Conduct any other act beyond the scope of this Licensing Agreement.
g.  This Licensing Agreement terminates immediately if the Licensee breaches
    this Agreement. The Licensor may claim compensation from the Licensee where
    the Licensee’s breach causes any damage to the Licensor.
h.  The laws of the People's Republic of China apply to this Licensing Agreement.
i.  This Agreement is made in both Chinese and English, and the Chinese version
    shall prevail the event of conflict.

*******************************************************************************/
let _rt = loadRuntime();

function _checkColor (color) {
    let isColor = true;

    if (typeof color === "string" && color.length === 6) {
        color = color.toUpperCase();

        for (let index = 0; index < 6; index ++) {
            let charCode = color.charCodeAt(index);

            if (charCode < 48 || (charCode > 57 && charCode < 65) || charCode > 70) {
                isColor = false;
                break;
            }
        }
    } else {
        isColor = false;
    }

    return isColor;
}

function _getCallBackObj(res) {
    let callBackObj = {};

    if (typeof res.success === "function") {
        callBackObj.success = res.success;
    }
    if (typeof res.fail === "function") {
        callBackObj.fail = res.fail;
    }
    if (typeof res.complete === "function") {
        callBackObj.complete = res.complete;
    }

    return callBackObj;
}

let _attributes = {
    showToast (res) {
        if (!res) {
            res = {};
        }

        let callBackObj = _getCallBackObj(res);
        _rt.callCustomCommand(callBackObj, "rt.showToast", JSON.stringify({
            title: res.title || "",
            icon: res.icon || "success",
            image: res.image || null,
            duration: res.duration || 1500,
            mask: !!res.mask
        }));
    },

    hideToast (res) {
        if (!res) {
            res = {};
        }

        let callBackObj = _getCallBackObj(res);
        _rt.callCustomCommand(callBackObj, "rt.hideToast");
    },

    showModal (res) {
        if (!res) {
            res = {};
        }

        if (!_checkColor(res.cancelColor)) {
            res.cancelColor = "000000";
        }
        if (!_checkColor(res.confirmColor)) {
            res.confirmColor = "576B95";
        }

        let callBackObj = _getCallBackObj(res);
        _rt.callCustomCommand(callBackObj, "rt.showModal", JSON.stringify({
            title: res.title || "",
            content: res.content || "",
            showCancel: !!res.showCancel,
            cancelText: res.cancelText || "取消",
            cancelColor: res.cancelColor,
            confirmText: res.confirmText || "确定",
            confirmColor: res.confirmColor
        }));
    },

    showActionSheet(res) {
        if (!res) {
            res = {};
        }

        if (!_checkColor(res.itemColor)) {
            res.itemColor = "000000";
        }

        let callBackObj = _getCallBackObj(res);
        _rt.callCustomCommand(callBackObj, "rt.showActionSheet", JSON.stringify({
            itemList: res.itemList || [],
            itemColor: res.itemColor
        }));
    },

    showLoading (res) {
        if (!res) {
            res = {};
        }

        let data = {};
        if (typeof res.success === "function") {
            data.success = res.success;
        }
        if (typeof res.fail === "function") {
            data.fail = res.fail;
        }
        if (typeof res.complete === "function") {
            data.complete = res.complete;
        }

        _rt.callCustomCommand(data, "rt.showLoading", JSON.stringify({
            title: res.title || "",
            mask: !!res.mask
        }));
    },

    hideLoading(res) {
        if (!res) {
            res = {};
        }

        let data = {};
        if (typeof res.success === "function") {
            data.success = res.success;
        }
        if (typeof res.fail === "function") {
            data.fail = res.fail;
        }
        if (typeof res.complete === "function") {
            data.complete = res.complete;
        }

        _rt.callCustomCommand(data, "rt.hideLoading");
    },

     trace(res) {
            if (!res) {
                res = {};
            }

            let data = {};
            if (typeof res.success === "function") {
                data.success = res.success;
            }
            if (typeof res.fail === "function") {
                data.fail = res.fail;
            }
            if (typeof res.complete === "function") {
                data.complete = res.complete;
            }

            _rt.callCustomCommand(data, "rt.trace", JSON.stringify({
                                   funId: res.funId,
                                   ext: {} // 其他扩展参数
                               }
                           ));
        }
};

Object.keys(_attributes).forEach(function (name) {
    _rt[name] = _attributes[name];
});